# Changelog

**23.5.4**
* Improved documentation
* Added further code quality templates

**23.5.3**
* Improved rendered readme file

**23.5.2**
* Templates render a trailing newline (to conform with Python linting)

**23.5.1**
* Initial release
